@@ -1,9 +1,9 @@
-.onLoad <- function(lib, pkg){
+.onAttach <- function(lib, pkg){
 
   packageStartupMessage("\n")
   packageStartupMessage("######################################################################################\n")
   packageStartupMessage("Easy Microarray Analysis\n")
   packageStartupMessage("EMA stable version\n")
-  packageStartupMessage("Current release : v1.3.2 - 01/03/12\n")
+  packageStartupMessage("Current release : v1.4.0 - 5/04/13\n")
   packageStartupMessage("######################################################################################\n")    
 }
